@@ -69,7 +69,7 @@ class CreateRepositoryTests(TestCase):
                 f.close()
 
     def _check_repo_contents(self, repo, expect_bare):
-        self.assertEquals(expect_bare, repo.bare)
+        self.assertEqual(expect_bare, repo.bare)
         self.assertFileContentsEqual('Unnamed repository', repo, 'description')
         self.assertFileContentsEqual('', repo, os.path.join('info', 'exclude'))
         self.assertFileContentsEqual(None, repo, 'nonexistent file')
@@ -81,14 +81,14 @@ class CreateRepositoryTests(TestCase):
         tmp_dir = tempfile.mkdtemp()
         self.addCleanup(shutil.rmtree, tmp_dir)
         repo = Repo.init_bare(tmp_dir)
-        self.assertEquals(tmp_dir, repo._controldir)
+        self.assertEqual(tmp_dir, repo._controldir)
         self._check_repo_contents(repo, True)
 
     def test_create_disk_non_bare(self):
         tmp_dir = tempfile.mkdtemp()
         self.addCleanup(shutil.rmtree, tmp_dir)
         repo = Repo.init(tmp_dir)
-        self.assertEquals(os.path.join(tmp_dir, '.git'), repo._controldir)
+        self.assertEqual(os.path.join(tmp_dir, '.git'), repo._controldir)
         self._check_repo_contents(repo, False)
 
     def test_create_memory(self):
@@ -119,7 +119,7 @@ class RepositoryTests(TestCase):
     def test_setitem(self):
         r = self._repo = open_repo('a.git')
         r["refs/tags/foo"] = 'a90fa2d900a17e99b433217e988c4eb4a2e9a097'
-        self.assertEquals('a90fa2d900a17e99b433217e988c4eb4a2e9a097',
+        self.assertEqual('a90fa2d900a17e99b433217e988c4eb4a2e9a097',
                           r["refs/tags/foo"].id)
 
     def test_delitem(self):
@@ -455,7 +455,7 @@ class BuildRepoTests(TestCase):
              commit_timestamp=12395, commit_timezone=0,
              author_timestamp=12395, author_timezone=0,
              encoding="iso8859-1")
-        self.assertEquals("iso8859-1", r[commit_sha].encoding)
+        self.assertEqual("iso8859-1", r[commit_sha].encoding)
 
     def test_commit_config_identity(self):
         # commit falls back to the users' identity if it wasn't specified
@@ -465,10 +465,10 @@ class BuildRepoTests(TestCase):
         c.set(("user", ), "email", "jelmer@apache.org")
         c.write_to_path()
         commit_sha = r.do_commit('message')
-        self.assertEquals(
+        self.assertEqual(
             "Jelmer <jelmer@apache.org>",
             r[commit_sha].author)
-        self.assertEquals(
+        self.assertEqual(
             "Jelmer <jelmer@apache.org>",
             r[commit_sha].committer)
 
@@ -536,7 +536,7 @@ class BuildRepoTests(TestCase):
              commit_timestamp=12395, commit_timezone=0,
              author_timestamp=12395, author_timezone=0,
              merge_heads=[merge_1])
-        self.assertEquals(
+        self.assertEqual(
             [self._root_commit, merge_1],
             r[commit_sha].parents)
 
@@ -745,7 +745,7 @@ class DictRefsContainerTests(RefsContainerTests, TestCase):
         self._refs._refs["refs/stash"] = "00" * 20
         expected_refs = dict(_TEST_REFS)
         expected_refs["refs/stash"] = "00" * 20
-        self.assertEquals(expected_refs, self._refs.as_dict())
+        self.assertEqual(expected_refs, self._refs.as_dict())
 
 
 class DiskRefsContainerTests(RefsContainerTests, TestCase):
@@ -839,10 +839,10 @@ class DiskRefsContainerTests(RefsContainerTests, TestCase):
         self.assertEqual(nines, refs['refs/heads/master'])
 
     def test_follow(self):
-        self.assertEquals(
+        self.assertEqual(
           ('refs/heads/master', '42d06bd4b77fed026b154d16493e5deab78f02ec'),
           self._refs._follow('HEAD'))
-        self.assertEquals(
+        self.assertEqual(
           ('refs/heads/master', '42d06bd4b77fed026b154d16493e5deab78f02ec'),
           self._refs._follow('refs/heads/master'))
         self.assertRaises(KeyError, self._refs._follow, 'refs/heads/loop')
@@ -926,7 +926,7 @@ class InfoRefsContainerTests(TestCase):
         expected_refs = dict(_TEST_REFS)
         del expected_refs['HEAD']
         expected_refs["refs/stash"] = "00" * 20
-        self.assertEquals(expected_refs, refs.as_dict())
+        self.assertEqual(expected_refs, refs.as_dict())
 
     def test_keys(self):
         refs = InfoRefsContainer(StringIO(_TEST_REFS_SERIALIZED))
